pub enum ManualRefInner {
Entity(EntityRef),
Group(GroupRef),
}Expand description
Inner target of a ManualRef cross-manual link.
Variants
Entity(EntityRef)
Link to a specific entity in the external manual.
Group(GroupRef)
Link to a group overview in the external manual.