pub struct ProtocolAttachment {
pub protocol_id: String,
pub payload: Vec<u8>,
}Expand description
Opaque protocol binding stored on contract and entity IR nodes.
The payload bytes encode exactly one arm of a protocol-specific top-level
oneof (for example HttpPayload or GrpcPayload).
Fields
protocol_id: StringStable protocol slug (for example "http", "grpc").
payload: Vec<u8>Encoded protocol-specific payload message.